@@ -1,6 +1,6 @@
 package Git::Repository::Plugin::GitHooks;
 # ABSTRACT: A Git::Repository plugin with some goodies for hook developers
-$Git::Repository::Plugin::GitHooks::VERSION = '2.1.5';
+$Git::Repository::Plugin::GitHooks::VERSION = '2.1.6';
 use parent qw/Git::Repository::Plugin/;
 
 use 5.010;
@@ -607,7 +607,6 @@ sub error {
     my ($git, $prefix, $message, $details) = @_;
     $message =~ s/\n*$//s;    # strip trailing newlines
     my $fmtmsg = "\n[$prefix] $message";
-    my $nocarp = $git->get_config(githooks => 'nocarp');
     if ($details) {
         # The details may have been generated by Carp::croak, in which case
         # it will contain a suffix telling where the error
@@ -615,7 +614,8 @@ sub error {
         # user is going to receive the error message produced by a server
         # hook he/she won't be able to use that information. So, we may have
         # to strip the context from the details.
-        $details =~ s/ at .*? line \d+(?: thread \d+)?\.?$//s if $nocarp;
+        $details =~ s/ at .*? line \d+(?: thread \d+)?\.?$//s
+            if $git->get_config(githooks => 'nocarp');
         $details =~ s/\n*$//s; # strip trailing newlines
         $details =~ s/^/  /gm; # prefix each line with two spaces
         $fmtmsg .= ":\n\n$details\n";
@@ -1140,7 +1140,7 @@ Git::Repository::Plugin::GitHooks - A Git::Repository plugin with some goodies f
 
 =head1 VERSION
 
-version 2.1.5
+version 2.1.6
 
 =head1 SYNOPSIS
 
